@@ -21,8 +21,18 @@ import numpy as np
 #                 fs, double type, emxArray_real_T *sig_out, double *delay, double
 #                 *err)
 
-def match_sig(refFile=None,testFile=None,outFile=None,audioType=1):
+def match_sig(refFile=None,testFile=None,outFile=None,audioType=0):
     """
+    Parameters
+    ----------
+    refFile
+    testFile
+    outFile
+    audioType  0:speech,1:music
+
+    Returns
+    -------
+
     """
 
     refstruct, refsamplerate,reflen = get_data_of_ctypes_(refFile)
